<?php

namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Teknisa\Model\Util\NovoCodigo;
use Zeedhi\Framework\Util\Functions;


class OrgOperController extends TeknisaCrud {
    
    protected $dataSourceNameGet1 = 'orgoper';
    protected $dataSourceNameSave1 = 'orgOperFull';
    protected $dataSourceNameGet2 = 'orgoperrel';
    protected $dataSourceNameGet3 = 'uniqueOperRelated';
    protected $dataSourceNameGet4 = 'getOperadores';
    protected $parameterBagColumns = array('P_NRORG', 'P_CRM_NRORGTRAB', 'NRORG');
    
    public function __construct($crudService, $parameterBag, $entityManager, $newCode, $environment, $util, $CRMParameters, $orgOperService) {
            
        $this->entityManager              = $entityManager;
        $this->connection                 = $entityManager->getConnection();
        $this->newCode                    = $newCode;
        $this->environment                = $environment;
        $this->crmParameters              = $CRMParameters;
        $this->util                       = $util;
        $this->orgOperService             = $orgOperService;
        
        parent::__construct($crudService, $parameterBag);
    }
    
    public function getOrganizations(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameGet1;
        parent::find($request, $response);
    }
    
    public function getRelatedOperators(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameGet2;
        parent::find($request, $response);
    }
    
    public function getNonRelatedOperators(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameGet3;
        parent::find($request, $response);
    }
    
    public function getOperadores(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameGet4;
        parent::find($request, $response);
    }
    
    public function setOrganizations(DTO\Request\Row $rows, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceNameSave1;
                
            $row = $rows->getRow();
                
            if (\Zeedhi\Framework\Util\Functions::arrayKeyExists('CRM_NRORGTRAB', $row)) {
                if (empty($row['CRM_NRORGTRAB'])) {
                    $row['CRM_NRORGTRAB'] = NovoCodigo::geraCodigo($row['NRORG'], "CRM_ORGANIZACAO", 1, 4, false, true);
                    if($row['CRM_NRORGTRAB'] == $row['NRORG']) {
                        $row['CRM_NRORGTRAB'] = NovoCodigo::geraCodigo($row['NRORG'], "CRM_ORGANIZACAO", 1, 4, false, true);
                    }
                }
            } else {
                $row['CRM_NRORGTRAB'] = NovoCodigo::geraCodigo($row['NRORG'], "CRM_ORGANIZACAO", 1, 4, false, true);
                if($row['CRM_NRORGTRAB'] == $row['NRORG']) {
                    $row['CRM_NRORGTRAB'] = NovoCodigo::geraCodigo($row['NRORG'], "CRM_ORGANIZACAO", 1, 4, false, true);
                }
            }
            $response->addDataSet(new DataSet('DADOS', array("CRM_NRORGTRAB" => intval($row['CRM_NRORGTRAB']))));
            parent::save($rows, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteOrganizations(DTO\Request\Row $rows, DTO\Response $response) {
        try {
            $row = $rows->getRow();
            
            if($this->orgOperService->verifyExistenceOfOperators($row)) {
                $message = new \Zeedhi\Framework\DTO\Response\Message('Não é possível excluir uma organização que possua operadores!<br><br>A organização foi inativada!', DTO\Response\Message::TYPE_WARNING);
                $response->addMessage($message);
                $row['IDATIVO'] = 'N';
                $this->dataSourceName = $this->dataSourceNameSave1;
                parent::save($rows, $response);
            } else {
                $this->dataSourceName = $this->dataSourceNameGet1;
                parent::delete($rows, $response);
            }
            
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function verifyMainOrg() {
        $this->orgOperService->verifyMainOrg($this->environment->getNrOrg());
    }
    
    public function setOperators(DTO\Request $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceNameGet2;
                
            $rows = $request->getDataSet()->getRows();
            
            $cdoperadores = array();
            $operadores = array();
            $nrorgtrab = $rows[0]['CRM_NRORGTRAB'];
            $nrorg = $rows[0]['NRORG'];
            $operInclusao = $this->environment->getCdOperador();
            
            foreach($rows as $row) {
                $cdoperadores[] = $row['CDOPERADOR'];
                $operadores[] = array("CDOPERADOR" => $row['CDOPERADOR'], "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO']);
            }

            parent::save($request, $response);
            
            foreach($operadores as $operador) {
                $this->orgOperService->setOperStatus($operador['CDOPERADOR'], $operador['NRPARCNEGOCIO'], $nrorg, $nrorgtrab, $operInclusao);
            }
            
            $response->addDataSet(new DataSet('DADOS', array("CDOPERADOR" => $cdoperadores)));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteOperators(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceNameGet3;
            
            $rows = $request->getDataSet()->getRows()[0];
            
            $retorno = $this->orgOperService->deleteOperators($rows);
            
            if(empty($retorno)) {
                $message = new \Zeedhi\Framework\DTO\Response\Message('Usuários excluídos com sucesso!<br><br>Usuários que tinham esta organização de trabalho como a atual foram modificados para a organização matriz!', DTO\Response\Message::TYPE_MESSAGE);
                if($message instanceof \Zeedhi\Framework\DTO\Response\Message) {
                    $response->addMessage($message);
                }
            } else {
                $msg = 'Impossível excluir o registro! O operador só possui relação com a organização matriz!<br><br>Adicione-o a outra organização antes de removê-lo da matriz.<br><br>Os registros que não foram excluídos foram os operadores: ' . $retorno . '.';
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($msg, DTO\Response\Message::TYPE_WARNING));
            }
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function alterarNrOrgTrab(DTO\Request\Row $rows, DTO\Response $response) {
        try {
            $auxRow = $rows->getRow();
            $nrorgtrab = $auxRow[1];
            foreach($auxRow[0] as $row) {
                $this->orgOperService->alterarNrOrgTrab($row, $this->crmParameters->getNrorg(), $nrorgtrab);
            }
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    protected function populateParameterBag(FilterCriteria $filterCriteria) {
        
        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
}