<?php

namespace Teknisa\CRM\Factory;

use Doctrine\ORM\EntityManager;

class crm00002001OportunidadeNegocioFactory
{

  protected $connection;

  public function __construct(EntityManager $entityManager)
  {
    $this->connection = $entityManager->getConnection();
  }

  public function reabrirOportunidade($row)
  {
    $params = array(
      "NRORG"         => $row['nrorg'],
      "NRSEQOPORT"    => $row['nrseqoport'],
      "CRM_NRORGTRAB" => $row['crm_nrorgtrab']
    );

    $query =
      "UPDATE
              CRM_OPORTUNI
            SET
              DTREALFECHA = NULL,
              NRSEQRESULEVOL = NULL,
              NRPARCCONC = NULL,
              VROPORT = NULL
            WHERE
              NRORG = :NRORG
              AND NRSEQOPORT = :NRSEQOPORT
              AND CRM_NRORGTRAB = :CRM_NRORGTRAB";

    $std = $this->connection->prepare($query);
    $std->execute($params);
  }

  public function isOperadorMaster($environment)
  {
    $params = array(
      "NRORG"         =>  $environment->getNrorg(),
      "CDOPERADOR"    =>  $environment->getCdOperador()
    );

    $query =
      "SELECT
                IDOPERMASTER
            FROM
                OPERADOR
            WHERE
                NRORG = :NRORG
                AND CDOPERADOR = :CDOPERADOR";

    $std = $this->connection->prepare($query);
    $std->execute($params);

    return $std->fetchAll();
  }

  public function transferirOportunidade($paramsTransferirOportu)
  {
    $updateTransfOportuni = "
        UPDATE 
          CRM_OPORTUNI 
        SET 
          NRPARCRESP = :NRPARCRESP
        WHERE 
          NRSEQOPORT = :NRSEQOPORT
          AND NRORG = :NRORG
          AND CRM_NRORGTRAB = :CRM_NRORGTRAB";

    try {
      $std = $this->connection->prepare($updateTransfOportuni);
      $std->execute($paramsTransferirOportu);
      // return $paramsTransferirOportu['NRSEQCONTATO'];
    } catch (\Exception $e) {
      throw $e;
    };
  }

  public function evolTransferirOportunidade($paramsEvolTransferirOportu)
  {
    $insertEvol = "
        INSERT INTO EVOLCONT (NRCONTATO,
                              NRSEQCONTATO,
                              DTHREVOLCONT,
                              IDSENEVOCONT,
                              IDTPEVOLCONT,
                              IDAGEEVOCONT,
                              CDOPEREVOL,
                              DTINCLUSAO,
                              IDANEXOEVOLCONT,
                              IDGERAFATURA,
                              IDEVOLPUBLICO,
                              IDRESPNOTA,
                              IDEVOLINTERNA,
                              DSEVOLCONT,
                              TXEVOLCONT,
                              NRSEQEVOLCONT,
                              IDATIVO,
                              CDOPERINCLUSAO,
                              NRORG,
                              CRM_NRORGTRAB)
                    VALUES (:NRCONTATO,
                            :NRSEQCONTATO,
                            SYSDATE,
                            :IDSENEVOCONT,
                            :IDTPEVOLCONT,
                            :IDAGEEVOCONT,
                            :CDOPEREVOL,
                            SYSDATE,
                            :IDANEXOEVOLCONT,
                            :IDGERAFATURA,
                            :IDEVOLPUBLICO,
                            :IDRESPNOTA,
                            :IDEVOLINTERNA,
                            :DSEVOLCONT,
                            :TXEVOLCONT,
                            :NRSEQEVOLCONT,
                            :IDATIVO,
                            :CDOPERINCLUSAO,
                            :NRORG,
                            :CRM_NRORGTRAB)";

    try {
      $std = $this->connection->prepare($insertEvol);
      $std->execute($paramsEvolTransferirOportu);
      return true;
    } catch (\Exception $e) {
      throw $e;
    };
  }

  public function buscarOportunidade($params)
  {
    try {
      $query = "
SELECT 
  VROPORTUNIDADE,
  VRPREVOPORTUNIDADE,
  NMTERMOPORTUNI,
  DSCORTERMOMETRO,
  DINCLUSAO,
  DIAS_DESDE_INCLUSAO,
  INCLUSAO,
  DTHRINIOPORTUNI,
  ULTIMA_EVOLUCAO,
  DIAS_DESDE_EVOLUCAO,
  QUANTIDADE_EVOLUCOES,
  NRSEQOPORT,
  NMOPORT,
  NRPARCOPORT,
  IDTPOPORT,
  NRPARCRESP,
  DTPREVFECHA,
  CDMODODIVULG,
  IDPARTPEPELINE,
  DTREALFECHA,
  NRSEQRESULEVOL,
  NRPARCCONC,
  DSOPORT,
  VROPORT,
  NRSEQFASENEGO,
  CDFILIAL,
  NRCONTATO,
  NRORG,
  CRM_NRORGTRAB,
  IDATIVO,
  DTINCLUSAO,
  DTULTATU,
  NRORGINCLUSAO,
  CDOPERINCLUSAO,
  NRORGULTATU,
  CDOPERULTATU,
  NRSEQCONTATO,
  NRSEQCLASSOPORT,
  VRPREVOPORT,
  NRTEMPOVIGENCIA,
  NRTERMOPORTUNI,
  NRCONCORRENTE,
  NMPRINCIPALPARC,
  NMOPERINCLUSAO,
  NMOPERULTATU,
  NMSEQFASENEGO,
  IDPERMITEFECHA,
  IDEXIGEVROPORT,
  NMCLASSOPORT,
  CDOPERADOR,
  NMPARCRESP,
  NMMODODIVULG,
  SITUACAO,
  DESCRESULEVOL,
  NMRAZSOCCONC
FROM 
  (SELECT 
    NVL(OPORT.VROPORT,0) AS VROPORTUNIDADE,
    NVL(OPORT.VRPREVOPORT, 0) AS VRPREVOPORTUNIDADE,
    TERM.NMTERMOPORTUNI,
    TERM.DSCORHEXADECIMAL DSCORTERMOMETRO,
    OPORT.DTINCLUSAO AS DINCLUSAO,
    ROUND((SELECT (SELECT SYSDATE FROM DUAL ) - (OPORT.DTINCLUSAO) FROM DUAL ) ) AS DIAS_DESDE_INCLUSAO, 
    TO_CHAR(TRUNC(OPORT.DTINCLUSAO),'DD/MM/YYYY') INCLUSAO, 
    EVOLCONT.DTHREVOLCONT AS ULTIMA_EVOLUCAO, 
    ROUND((SELECT (SELECT SYSDATE FROM DUAL ) - (EVOLCONT.DTHREVOLCONT) FROM DUAL ) ) AS DIAS_DESDE_EVOLUCAO,
    (SELECT COUNT(1) FROM EVOLCONT
      LEFT JOIN CRM_OPORTUNI OPOR
        ON EVOLCONT.NRSEQCONTATO = OPOR.NRSEQCONTATO
            AND EVOLCONT.NRORG = OPOR.NRORG
     WHERE OPOR.NRSEQCONTATO = OPORT.NRSEQCONTATO
     GROUP BY  NRSEQOPORT ) AS QUANTIDADE_EVOLUCOES, OPORT.*, PARC.NMPRINCIPALPARC NMPRINCIPALPARC, OPER.NMOPERADOR NMOPERINCLUSAO, OPERATU.NMOPERADOR NMOPERULTATU, FASE.NMSEQFASENEGO, FASE.IDPERMITEFECHA, FASE.IDEXIGEVROPORT, CLAS.NMCLASSOPORT, RESP.CDOPERADOR, RESP.NMOPERADOR NMPARCRESP, MODO.NMMODODIVULG, DECODE(OPORT.DTREALFECHA,NULL,'A','F') AS SITUACAO, REST.DESCRESULEVOL, CONC.NMRAZSOCCONC
    FROM CRM_OPORTUNI OPORT
    LEFT JOIN OPERADOR OPER
      ON OPER.CDOPERADOR = OPORT.CDOPERINCLUSAO
    LEFT JOIN OPERADOR OPERATU
      ON OPERATU.CDOPERADOR = OPORT.CDOPERULTATU
    LEFT JOIN EVOLCONT
      ON EVOLCONT.NRSEQCONTATO = OPORT.NRSEQCONTATO
      AND EVOLCONT.NRORG = OPORT.NRORG
    LEFT JOIN PARCNEGOCIO PARC
      ON PARC.NRORG = OPORT.NRORG
      AND PARC.NRPARCNEGOCIO = OPORT.NRPARCOPORT
    LEFT JOIN CRM_FASENEGOCI FASE
      ON OPORT.NRSEQFASENEGO = FASE.NRSEQFASENEGO
      AND OPORT.IDATIVO = FASE.IDATIVO
      AND OPORT.NRORG = FASE.NRORG
    LEFT JOIN CRM_CLASSOPORTUNI CLAS
      ON OPORT.NRSEQCLASSOPORT = CLAS.NRSEQCLASSOPORT
      AND OPORT.IDATIVO = CLAS.IDATIVO
      AND OPORT.NRORG = CLAS.NRORG
    JOIN OPERADOR RESP
      ON OPORT.NRPARCRESP = RESP.NRPARCNEGOCIO
      AND OPORT.IDATIVO = RESP.IDATIVO
      AND OPORT.NRORG = RESP.NRORG
    LEFT JOIN MODODIVULG MODO
      ON OPORT.CDMODODIVULG = MODO.CDMODODIVULG
      AND OPORT.IDATIVO = MODO.IDATIVO
      AND OPORT.NRORG = MODO.NRORG
    LEFT JOIN CRM_RESULTEVOL REST
      ON OPORT.NRSEQRESULEVOL = REST.NRSEQRESULEVOL
      AND OPORT.NRORG = REST.NRORG
    LEFT JOIN CRM_CONCORRENTE CONC
      ON OPORT.NRCONCORRENTE = CONC.NRCONCORRENTE
      AND OPORT.NRORG = CONC.NRORG
    LEFT JOIN CRM_TERMOPORTUNI TERM
      ON TERM.NRORG = OPORT.NRORG
      AND TERM.NRTERMOPORTUNI = OPORT.NRTERMOPORTUNI
    WHERE 
      OPORT.NRORG = :P_NRORG
      AND OPORT.IDATIVO = 'S'
      AND OPORT.NRSEQOPORT = :P_NRSEQOPORT
      AND OPORT.CRM_NRORGTRAB = :P_CRM_NRORGTRAB)";

      $std = $this->connection->prepare($query);
    $std->executeQuery($params);
      $result = $std->fetchAll();
      if (isset($result[0])) {
        return $result[0];
      } else {
        return $result;
      }
    } catch (\Exception $e) {
      throw $e;
    };
  }

  public function searchNrContato($paramsQuery)
  {
    try {
      $query = "SELECT 
                     NRCONTATO, 
                     NRSEQCONTATO 
                   FROM 
                     CONTATO
                    WHERE 
                      NRPARCNEGOCIO = :NRPARCNEGOCIO
                      AND NRORG = :NRORG";

      $std = $this->connection->prepare($query);
      $std->execute($paramsQuery);

      $resp = $std->fetchAll();

      if (!empty($resp)) {
        return $resp[0];
      } else {
        return array();
      }
    } catch (\Exception $e) {
      $e->getMessage();
    }
  }

  public function closeOportByOccurrenceFactory($params)
  {

    try {
      $query = "UPDATE CRM_OPORTUNI
                SET
                IDATIVO = :IDATIVO,
                DTREALFECHA = :DTREALFECHA,
                NRSEQFASENEGO = :NRSEQFASENEGO,
                CDOPERULTATU = :CDOPERULTATU
                  WHERE
                    NRSEQOPORT = :NRSEQOPORT
                    AND NRPARCRESP = :NRPARCRESP
                    AND CRM_NRORGTRAB = :CRM_NRORGTRAB";

      $std = $this->connection->prepare($query);
      $std->executeQuery($params);
    } catch (\Exception $e) {
      throw $e;
    };
  }

  public function setEvolutionFactory($params)
  {
 
    try {
      $query = "
      INSERT INTO EVOLCONT 
        (NRCONTATO,
        NRSEQCONTATO,
        IDSENEVOCONT,
        IDTPEVOLCONT,
        IDAGEEVOCONT,
        CDOPEREVOL,
        CDOPERULTATU,
        NRSEQFASENEGO,
        NRTERMOPORTUNI,
        CDTIPOCONT,
        NRSEQRESULEVOL,
        CDMOTIEVOCON,
        IDANEXOEVOLCONT,
        IDGERAFATURA,
        IDEVOLPUBLICO,
        IDRESPNOTA,
        DTHREVOLCONT,
        IDEVOLINTERNA,
        DSEVOLCONT,
        TXEVOLCONT,
        NRSEQEVOLCONT,
        IDATIVO,
        CDOPERINCLUSAO,
        NRORG,
        CRM_NRORGTRAB) 
        VALUES 
        (:NRCONTATO,
        :NRSEQCONTATO,
        :IDSENEVOCONT,
        :IDTPEVOLCONT,
        :IDAGEEVOCONT,
        :CDOPEREVOL,
        :CDOPERULTATU,
        :NRSEQFASENEGO,
        :NRTERMOPORTUNI,
        :CDTIPOCONT,
        :NRSEQRESULEVOL,
        :CDMOTIEVOCON,
        :IDANEXOEVOLCONT,
        :IDGERAFATURA,
        :IDEVOLPUBLICO,
        :IDRESPNOTA,
         SYSDATE,
        :IDEVOLINTERNA,
        :DSEVOLCONT,
        :TXEVOLCONT,
        :NRSEQEVOLCONT,
        :IDATIVO,
        :CDOPERINCLUSAO,
        :NRORG,
        :CRM_NRORGTRAB
        )";

      $std = $this->connection->prepare($query);
      $std->executeQuery($params);
    } catch (\Exception $e) {

      throw $e;

    };
  }

  public function callForConcludeOportTaskFactory ($paramsDeactivateTask)
  {

    $update = "UPDATE FILACONTATO
                SET DTREALFILACONTA     = SYSDATE,
                    DSDETEFILACONTA     = :DSDETEFILACONTA,
                    IDATIVO             = 'N'
                  WHERE NRSEQFILACONTA  = :NRSEQFILACONTA
                    AND NRORG           = :NRORG";

    try {

      $std = $this->connection->prepare($update);
      $std->executeQuery($paramsDeactivateTask);

    } catch (\Exception $e) {

      throw $e;

    };

  }

  public function findTasksFactory($params)
  {

    try {

      $query = "SELECT NRSEQFILACONTA
                  FROM FILACONTATO 
                    WHERE NRSEQCONTATO = :NRSEQCONTATO
                      AND DTREALFILACONTA IS NULL";

      $std = $this->connection->prepare($query);
      $std->executeQuery($params);
      $result = $std->fetchAll();
      return $result[0];

    } catch (\Exception $e) {

    

    }
  }
}
